@@ -5,10 +5,10 @@ from aurora import Model
 class Users(Model):
 
     # Model columns
-    id = Model.column(datatype='int', size='lg', not_null=True)
-    username = Model.column(datatype='str', size='xs', unique=True, not_null=True)
-    email = Model.column(datatype='str', size='xs', unique=True, not_null=True)
-    password = Model.column(datatype='str', size='sm', not_null=True)
+    id = Model.column(datatype='integer', not_null=True)
+    username = Model.column(datatype='varchar(50)', unique=True, not_null=True)
+    email = Model.column(datatype='varchar(50)', unique=True, not_null=True)
+    password = Model.column(datatype='varchar(500)', not_null=True)
 
     # Model constructor
     def __init__(self):
